<?php

/**
 * Drupal\user_reference_node_access\Form\UserReferenceNodeAccessConfigurationForm.
 */

namespace Drupal\user_reference_node_access\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines our form class.
 */
class UserReferenceNodeAccessConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_reference_node_access_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'user_reference_node_access.user_reference_node_access_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('user_reference_node_access.user_reference_node_access_settings');

    // Set default values as none exist until form is saved.
		$userGrantView = 1;
		$userGrantEdit = 0;
		$userGrantDelete = 0;
		$ownerGrantView = 1;
		$ownerGrantEdit = 1;
		$ownerGrantDelete = 1;

		// Check if our form values exist.
		if ($config->get('user_reference_grants_view') != NULL) {
			$userGrantView = $config->get('user_reference_grants_view');
		}
		if ($config->get('user_reference_grants_edit') != NULL) {
			$userGrantEdit = $config->get('user_reference_grants_edit');
		}
		if ($config->get('user_reference_grants_delete') != NULL) {
			$userGrantDelete = $config->get('user_reference_grants_delete');
		}
		if ($config->get('user_reference_grants_view') != NULL) {
			$ownerGrantEdit = $config->get('node_author_grants_view');
		}
		if ($config->get('user_reference_grants_edit') != NULL) {
			$ownerGrantEdit = $config->get('node_author_grants_edit');
		}
		if ($config->get('user_reference_grants_delete') != NULL) {
			$ownerGrantDelete = $config->get('node_author_grants_delete');
		}

    $yes_no_options = [
      '1' => t('Yes'),
      '0' => t('No'),
    ];

    $form['user_reference_node_access_heading'] = [
      '#type' => 'item',
      '#markup' => t('<h2>Available User Reference Access Settings</h2>'),
    ];

    $form['user_reference_node_access_note'] = [
      '#type' => 'item',
      '#markup' => t('
        <p><strong>**Warning:</strong> if you change these settings, existing nodes will need to be resaved to reflect changes.</p>
      '),
    ];

    $form['user_reference_field_name_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => t('Basic Settings'),
      '#weight' => 1,
      '#attributes' => [
        'class' => [
          'user-reference-field-name-wrapper',
        ],
      ],
    ];
    $form['user_reference_field_name_wrapper']['user_reference_field_name'] = [
      '#type' => 'textfield',
      '#attributes' => [
        'type' => 'text',
      ],
      '#title' => t('User reference field name (field must exist on node)'),
      '#required' => TRUE,
      '#description' => t('If a node has this field, it will follow the node access settings below.'),
      '#maxlength' => 160,
      '#size' => 60,
      '#default_value' => $config->get('user_reference_field_name'),
    ];

    $form['user_reference_grants_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => t('Referenced Users Settings'),
      '#weight' => 2,
      '#attributes' => [
        'class' => [
          'user-reference-grants-wrapper',
        ],
      ],
    ];
    $form['user_reference_grants_wrapper']['user_reference_grants_view'] = [
      '#type' => 'radios',
      '#title' => t('Allow referenced users to view node?'),
      '#description' => t('<em>Yes</em> will set view grants for all referenced users.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $userGrantView,
    ];
    $form['user_reference_grants_wrapper']['user_reference_grants_edit'] = [
      '#type' => 'radios',
      '#title' => t('Allow referenced users to edit node?'),
      '#description' => t('<em>Yes</em> will set edit grants for all referenced users.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $userGrantEdit,
    ];
    $form['user_reference_grants_wrapper']['user_reference_grants_delete'] = [
      '#type' => 'radios',
      '#title' => t('Allow referenced users to delete node?'),
      '#description' => t('<em>Yes</em> will set delete grants for all referenced users.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $userGrantDelete,
    ];

    $form['node_author_grants_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => t('Node Author Settings'),
      '#weight' => 3,
      '#attributes' => [
        'class' => [
          'node-author-grants-wrapper',
        ],
      ],
    ];
    $form['node_author_grants_wrapper']['node_author_grants_view'] = [
      '#type' => 'radios',
      '#title' => t('Allow node author to view node?'),
      '#description' => t('<em>Yes</em> will set view grants for node author.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $ownerGrantView,
    ];
    $form['node_author_grants_wrapper']['node_author_grants_edit'] = [
      '#type' => 'radios',
      '#title' => t('Allow node author to edit node?'),
      '#description' => t('<em>Yes</em> will set edit grants for node author.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $ownerGrantEdit,
    ];
    $form['node_author_grants_wrapper']['node_author_grants_delete'] = [
      '#type' => 'radios',
      '#title' => t('Allow node author to delete node?'),
      '#description' => t('<em>Yes</em> will set delete grants for node author.'),
      '#required' => TRUE,
      '#options' => $yes_no_options,
      '#default_value' => $ownerGrantDelete,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('user_reference_grants_view', $values['user_reference_grants_view']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('user_reference_grants_edit', $values['user_reference_grants_edit']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('user_reference_grants_delete', $values['user_reference_grants_delete']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('node_author_grants_view', $values['node_author_grants_view']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('node_author_grants_edit', $values['node_author_grants_edit']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('node_author_grants_delete', $values['node_author_grants_delete']);
    $this->config('user_reference_node_access.user_reference_node_access_settings')->set('user_reference_field_name', $values['user_reference_field_name'])->save();
    parent::submitForm($form, $form_state);
  }
}
